@@ -1,6 +1,7 @@
 use std::process::Command;
 
 const BATS: &str = "./tests/bats/bin/bats";
+const SKIP_BATS_TESTS: Option<&str> = std::option_env!("SKIP_BATS_TESTS");
 
 #[test]
 fn basic_syncronous_tests() {
@@ -12,6 +13,11 @@ fn basic_syncronous_tests() {
 // TODO: Format tests for JSON, CSV, TSV
 
 fn run_bats_test_file(test_file_path: &str) {
+    if let Some("1") = SKIP_BATS_TESTS {
+        println!("SKIPPING TESTS.");
+        return;
+    }
+
     let exit_code = Command::new(BATS)
         .arg(test_file_path)
         .spawn()
